@@ -40,6 +40,9 @@ public:
 
 	virtual void start(const QDBusConnection &connection);
 
+	virtual qint64 processId() const;
+
+	[[deprecated("Use processId() instead.")]]
 	virtual Q_PID pid() const;
 
 	virtual const QProcess & underlyingProcess() const;
